@@ -37,7 +37,6 @@
 #include <libpanel-util/panel-error.h>
 #include <libpanel-util/panel-show.h>
 
-#include "nothing.h"
 #include "panel-util.h"
 #include "panel.h"
 #include "menu.h"
@@ -57,28 +56,6 @@ panel_context_menu_show_help (GtkWidget *w,
 			 "mate-user-guide", "gospanel-1", NULL);
 }
 
-static gboolean
-panel_context_menu_check_for_screen (GtkWidget *w,
-				     GdkEvent *ev,
-				     gpointer data)
-{
-	static int times = 0;
-	if (ev->type != GDK_KEY_PRESS)
-		return FALSE;
-	if (ev->key.keyval == GDK_KEY_f ||
-	    ev->key.keyval == GDK_KEY_F) {
-		times++;
-		if (times == 3) {
-			times = 0;
-#if !GTK_CHECK_VERSION (3, 0, 0)
-			/* FIXME re-add once GTK3 support is fixed */
-			start_screen_check ();
-#endif
-		}
-	}
-	return FALSE;
-}
-
 static void
 panel_context_menu_show_about_dialog (GtkWidget *menuitem)
 {
@@ -150,9 +127,6 @@ panel_context_menu_show_about_dialog (GtkWidget *menuitem)
 	g_signal_connect (about, "destroy",
 			  G_CALLBACK (gtk_widget_destroyed),
 			  &about);
-	g_signal_connect (about, "event",
-			  G_CALLBACK (panel_context_menu_check_for_screen),
-			  NULL);
 
 	g_signal_connect (about, "response",
 			  G_CALLBACK (gtk_widget_destroy),
@@ -310,7 +284,6 @@ panel_context_menu_create (PanelWidget *panel)
 	g_object_set_data (G_OBJECT (retval), "menu_panel", panel);
 
 /* Set up theme and transparency support */
-#if GTK_CHECK_VERSION (3, 0, 0) 
 	GtkWidget *toplevel = gtk_widget_get_toplevel (retval);
 /* Fix any failures of compiz/other wm's to communicate with gtk for transparency */
 	GdkScreen *screen = gtk_widget_get_screen(GTK_WIDGET(toplevel));
@@ -321,7 +294,6 @@ panel_context_menu_create (PanelWidget *panel)
 	context = gtk_widget_get_style_context (GTK_WIDGET(toplevel));
 	gtk_style_context_add_class(context,"gnome-panel-menu-bar");
 	gtk_style_context_add_class(context,"mate-panel-menu-bar");
-#endif
 
 	return retval;
 }
